﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using static System.Threading.Thread;  // Sleep()

namespace RobotTestGraphical
{
    public class RobotProgram(UniversalRobot r)
    {
        public event EventHandler<string> NewLogMessageCreated = delegate { };

        protected void Log(string message)
        {
            NewLogMessageCreated?.Invoke(this, message);
        }
        public void Run()
        {
            var DefaultPose = new Pose(.1286, -.3465, 0.549, 2, 0, 0);

            Log("↩️ To default position");
            r.MoveJ(DefaultPose);

            Log($"Current pose: {r.GetPose()}");

            Log("🟢 Opening gripper");
            r.GripperGrip(width: 40, force: 40);
            Sleep(400);

            /*
             * The following sequence picks objects which are on a 5 cm grid and displaces them 10 cm to the right.
             */
            for (int x = 0; x < 2; x++)
            {
                for (int y = 0; y < 2; y++)
                {
                    var movingOverPose = new Pose(.125 + x * .05, -.425 + y * .05, -.08, 3.1, 0, 0);
                    var grippingPose = new Pose(movingOverPose);
                    grippingPose.Z -= 0.05;

                    Log("🟢 Moving over the object");
                    r.MoveJ(movingOverPose);

                    Log("🟢 Reaching object");
                    r.MoveJ(grippingPose);

                    Log("🟢 Closing gripper");
                    r.GripperGrip(17);
                    Sleep(200);

                    var pose = new Pose(grippingPose);

                    Log("🟢 Moving up Z+");
                    pose.Z += .08;
                    r.MoveJ(pose);

                    Log("🟢 Moving right X+");
                    pose.X += .1;
                    r.MoveJ(pose);

                    Log("🟢 Moving down Z-");
                    pose.Z -= .08;
                    r.MoveJ(pose);

                    Log("🟢 Opening gripper");
                    r.GripperGrip(40);
                    Sleep(400);

                    Log("🟢 Moving up Z+");
                    pose.Z += .08;
                    r.MoveJ(pose);
                }
            }

            Log("↩️ To default position");
            r.MoveJ(DefaultPose);
            Log("🏁 End");
        }
    }
}
